==> haystack-0.5.0%2B2.tar.gz: test/HDict_test.dart <==
///
/// Copyright (c) 2018, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

library haystack.dict_test;

import 'package:haystack/core.dart';
import 'package:test/test.dart';

import 'utils.dart';

void main () {
  group('Test empty HDict', () {
    HDict tags = new HDictBuilder().toDict();

    test('equality', () {
      expect(identical(tags, HDict.EMPTY), equals(true));
      expect(tags == HDict.EMPTY, equals(true));
    });

    test('size', () {
      expect(tags.size, equals(0));
      expect(tags.isEmpty, equals(true));
    });

    test('missing tag', () {
      expect(tags.has("foo"), equals(false));
      expect(tags.missing("foo"), equals(true));
      expect(tags.get("foo", checked:false), equals(null));
      expect(() => tags.get("foo"), throwsA(new isInstanceOf<UnknownNameError>()));
      expect(() => tags.get("foo", checked:true), throwsA(new isInstanceOf<UnknownNameError>()));
    });
  });

  test('Test isTagName', () {
    expect(HDict.isTagName(""), equals(false));
    expect(HDict.isTagName("A"), equals(false));
    expect(HDict.isTagName(" "), equals(false));
    expect(HDict.isTagName("a"), equals(true));
    expect(HDict.isTagName("a_B_19"), equals(true));
    expect(HDict.isTagName("a b"), equals(false));
    expect(HDict.isTagName("a\u0128"), equals(false));
    expect(HDict.isTagName("a\u0129x"), equals(false));
    expect(HDict.isTagName("a\uabcdx"), equals(false));
  });

  group('Test basics', () {
    HDict tags = new HDictBuilder()
    .add("id", new HRef("aaaa-bbbb"))
    .add("site")
    .add("geoAddr", "Richmond, Va")
    .add("area", 1200, "ft")
    .add("date", new HDate(2000, 12, 3))
    .toDict();

    test('size', () {
      expect(tags.size, equals(5));
      expect(tags.isEmpty, equals(false));
    });

    test('configured tag', () {
      expect(tags.get("id"),      equals(new HRef("aaaa-bbbb")));
      expect(tags.get("site"),    equals(HMarker.VAL));
      expect(tags.get("geoAddr"), equals(new HStr("Richmond, Va")));
      expect(tags.get("area"),    equals(new HNum(1200, "ft")));
      expect(tags.get("date"),    equals(new HDate(2000, 12, 3)));
    });

    test('missing tag', () {
      expect(tags.has("foo"), equals(false));
      expect(tags.missing("foo"), equals(true));
      expect(tags.get("foo", checked:false), equals(null));
      expect(() => tags.get("foo"), throwsA(new isInstanceOf<UnknownNameError>()));
      expect(() => tags.get("foo", checked:true), throwsA(new isInstanceOf<UnknownNameError>()));
    });
  });

  test('Test equality', () {
    HDict a = new HDictBuilder().add("x").toDict();

    expect(a == new HDictBuilder().add("x").toDict(), equals(true));
    expect(a == new HDictBuilder().add("x", 3).toDict(), equals(false));
    expect(a == new HDictBuilder().add("y").toDict(), equals(false));
    expect(a == new HDictBuilder().add("x").add("y").toDict(), equals(false));

    a = new HDictBuilder().add("x").add("y", "str").toDict();
    expect(a == new HDictBuilder().add("x").add("y", "str").toDict(), equals(true));
    expect(a == new HDictBuilder().add("y", "str").add("x").toDict(), equals(true));
    expect(a == new HDictBuilder().add("x", "str").add("y", "str").toDict(), equals(false));
    expect(a == new HDictBuilder().add("x").add("y", "strx").toDict(), equals(false));
    expect(a == new HDictBuilder().add("y", "str").toDict(), equals(false));
    expect(a == new HDictBuilder().add("x").toDict(), equals(false));
    expect(a == new HDictBuilder().add("x").add("yy", "str").toDict(), equals(false));
  });

  test('Test zinc', () {
    verifyZinc( HDict.EMPTY, "{}");
    verifyZinc( new HDictBuilder().add("foo_12").toDict(), "{foo_12}");
    verifyZinc( new HDictBuilder().add("fooBar", 123, "ft").toDict(),
        "{fooBar:123ft}");
    verifyZinc(
        new HDictBuilder().add("dis", "Bob").add("bday", new HDate(1970,6,3)).add("marker").toDict(),
        "{dis:\"Bob\" bday:1970-06-03 marker}");

    // nested dict
    verifyZinc(
        new HDictBuilder().add("auth", HDict.EMPTY).toDict(), "{auth:{}}");
    verifyZinc(
        new HDictBuilder().add("auth",
            new HDictBuilder().add("alg", "scram").add("c", 10000).add("marker").toDict()
        ).toDict(),
        "{auth:{alg:\"scram\" c:10000 marker}}");

    // nested list
    verifyZinc(
        new HDictBuilder().add("arr", new HList([new HNum(1.0), new HNum(2), new HNum(3)]))
            .add("x").toDict(),
        "{arr:[1.0,2,3] x}");
  });

  test('Test dis', () {
    expect(new HDictBuilder().add("id", new HRef("a")).toDict().dis(), equals("a"));
    expect(new HDictBuilder().add("id", new HRef("a", "b")).toDict().dis(), equals("b"));
    expect(new HDictBuilder().add("id", new HRef("a")).add("dis", "d").toDict().dis(), equals("d"));
  });

}

==> haystack-1.0.0-dev.1.0%2B2.tar.gz: test/HDict_test.dart <==
///
/// Copyright (c) 2018, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

library haystack.dict_test;

import 'package:haystack/haystack.dart';
import 'package:test/test.dart';

import 'utils.dart';

void main () {
  group('Test empty HDict', () {
    HDict tags = new HDictBuilder().toDict();

    test('equality', () {
      expect(identical(tags, HDict.EMPTY), equals(true));
      expect(tags == HDict.EMPTY, equals(true));
    });

    test('size', () {
      expect(tags.size, equals(0));
      expect(tags.isEmpty, equals(true));
    });

    test('missing tag', () {
      expect(tags.has("foo"), equals(false));
      expect(tags.missing("foo"), equals(true));
      expect(tags.get("foo", checked:false), equals(null));
      expect(() => tags.get("foo"), throwsA(const TypeMatcher<UnknownNameError>()));
      expect(() => tags.get("foo", checked:true), throwsA(const TypeMatcher<UnknownNameError>()));
    });
  });

  test('Test isTagName', () {
    expect(HDict.isTagName(""), equals(false));
    expect(HDict.isTagName("A"), equals(false));
    expect(HDict.isTagName(" "), equals(false));
    expect(HDict.isTagName("a"), equals(true));
    expect(HDict.isTagName("a_B_19"), equals(true));
    expect(HDict.isTagName("a b"), equals(false));
    expect(HDict.isTagName("a\u0128"), equals(false));
    expect(HDict.isTagName("a\u0129x"), equals(false));
    expect(HDict.isTagName("a\uabcdx"), equals(false));
  });

  group('Test basics', () {
    HDict tags = new HDictBuilder()
    .add("id", new HRef("aaaa-bbbb"))
    .add("site")
    .add("geoAddr", "Richmond, Va")
    .add("area", 1200, "ft")
    .add("date", new HDate(2000, 12, 3))
    .toDict();

    test('size', () {
      expect(tags.size, equals(5));
      expect(tags.isEmpty, equals(false));
    });

    test('configured tag', () {
      expect(tags.get("id"),      equals(new HRef("aaaa-bbbb")));
      expect(tags.get("site"),    equals(HMarker.VAL));
      expect(tags.get("geoAddr"), equals(new HStr("Richmond, Va")));
      expect(tags.get("area"),    equals(new HNum(1200, "ft")));
      expect(tags.get("date"),    equals(new HDate(2000, 12, 3)));
    });

    test('missing tag', () {
      expect(tags.has("foo"), equals(false));
      expect(tags.missing("foo"), equals(true));
      expect(tags.get("foo", checked:false), equals(null));
      expect(() => tags.get("foo"), throwsA(const TypeMatcher<UnknownNameError>()));
      expect(() => tags.get("foo", checked:true), throwsA(const TypeMatcher<UnknownNameError>()));
    });
  });

  test('Test equality', () {
    HDict a = new HDictBuilder().add("x").toDict();

    expect(a == new HDictBuilder().add("x").toDict(), equals(true));
    expect(a == new HDictBuilder().add("x", 3).toDict(), equals(false));
    expect(a == new HDictBuilder().add("y").toDict(), equals(false));
    expect(a == new HDictBuilder().add("x").add("y").toDict(), equals(false));

    a = new HDictBuilder().add("x").add("y", "str").toDict();
    expect(a == new HDictBuilder().add("x").add("y", "str").toDict(), equals(true));
    expect(a == new HDictBuilder().add("y", "str").add("x").toDict(), equals(true));
    expect(a == new HDictBuilder().add("x", "str").add("y", "str").toDict(), equals(false));
    expect(a == new HDictBuilder().add("x").add("y", "strx").toDict(), equals(false));
    expect(a == new HDictBuilder().add("y", "str").toDict(), equals(false));
    expect(a == new HDictBuilder().add("x").toDict(), equals(false));
    expect(a == new HDictBuilder().add("x").add("yy", "str").toDict(), equals(false));
  });

  test('Test zinc', () {
    verifyZinc( HDict.EMPTY, "{}");
    verifyZinc( new HDictBuilder().add("foo_12").toDict(), "{foo_12}");
    verifyZinc( new HDictBuilder().add("fooBar", 123, "ft").toDict(),
        "{fooBar:123ft}");
    verifyZinc(
        new HDictBuilder().add("dis", "Bob").add("bday", new HDate(1970,6,3)).add("marker").toDict(),
        "{dis:\"Bob\" bday:1970-06-03 marker}");

    // nested dict
    verifyZinc(
        new HDictBuilder().add("auth", HDict.EMPTY).toDict(), "{auth:{}}");
    verifyZinc(
        new HDictBuilder().add("auth",
            new HDictBuilder().add("alg", "scram").add("c", 10000).add("marker").toDict()
        ).toDict(),
        "{auth:{alg:\"scram\" c:10000 marker}}");

    // nested list
    verifyZinc(
        new HDictBuilder().add("arr", new HList([new HNum(1.0), new HNum(2), new HNum(3)]))
            .add("x").toDict(),
        "{arr:[1.0,2,3] x}");
  });

  test('Test dis', () {
    expect(new HDictBuilder().add("id", new HRef("a")).toDict().dis(), equals("a"));
    expect(new HDictBuilder().add("id", new HRef("a", "b")).toDict().dis(), equals("b"));
    expect(new HDictBuilder().add("id", new HRef("a")).add("dis", "d").toDict().dis(), equals("d"));
  });

}
